@@ -1164,7 +1164,6 @@ class Vector(object):
                            spref=None,
                            spref_string=None,
                            spref_string_type='wkt',
-                           vector_type=None,
                            out_epsg=4326,
                            attributes=None,
                            attribute_types=None,
@@ -1176,7 +1175,6 @@ class Vector(object):
         :param spref: OSR Spatial reference object
         :param spref_string: WKT representation of the spatial reference for the Vector object
         :param spref_string_type: Spatial reference string type (e.g. 'wkt', 'proj4', 'epsg'; default: 'wkt)
-        :param vector_type: Type of vector geometry (e.g. 'point','polygon','multipolygon','line'; default: 'polygon')
         :param out_epsg: EPSG SRID for the geometry object
         :param attributes: Dictionary or list of dictionaries of feature attributes.
                            The 'key' names in this list of dicts should match exactly with attribute_types
@@ -1196,12 +1194,15 @@ class Vector(object):
         else:
             raise TypeError("Unsupported geometry type")
 
+        first_geom = geom_func[geom_string_type](geom_strings[0])
+        vector_type = first_geom.GetGeometryName()
+
         vector = cls(name='vector_from_geom_list',
                      spref=spref,
                      spref_str=spref_string,
                      spref_str_type=spref_string_type,
                      epsg=out_epsg,
-                     geom_type=vector_type,
+                     geom_type=vector_type.lower(),
                      in_memory=True,
                      verbose=verbose,
                      primary_key='fid',
